pub fn from_reader<T: DeserializeOwned, R: BufRead>(
input: R,
) -> Result<T, DumpError>Expand description
A helper function for decoding and decompressing data from a reader
pub fn from_reader<T: DeserializeOwned, R: BufRead>(
input: R,
) -> Result<T, DumpError>A helper function for decoding and decompressing data from a reader