from_uncompressed_data

Function from_uncompressed_data 

pub fn from_uncompressed_data<T: DeserializeOwned>(
    v: &[u8],
) -> Result<T, DumpError>
To be used when deserializing a SyntaxSet from raw data, for example data that has been embedded in your own binary with the include_bytes! macro.