pub fn dump_to_file<T: Serialize, P: AsRef<Path>>(
o: &T,
path: P,
) -> Result<(), DumpError>Expand description
Dumps an encodable object to a file at a given path, in the same format as dump_to_writer
If a file already exists at that path it will be overwritten. The files created are encoded with
the bincode crate and then compressed with the flate2 crate.